@@ -9,19 +9,20 @@
 #define _mysql_version_h
 
 #define PROTOCOL_VERSION            10
-#define MYSQL_SERVER_VERSION       "5.7.29"
-#define MYSQL_BASE_VERSION         "mysqld-5.7"
+#define MYSQL_SERVER_VERSION       "8.0.28"
+#define MYSQL_BASE_VERSION         "mysqld-8.0"
 #define MYSQL_SERVER_SUFFIX_DEF    ""
-#define FRM_VER                     6
-#define MYSQL_VERSION_ID            50729
+#define MYSQL_VERSION_ID            80028
 #define MYSQL_PORT                  3306
+#define MYSQL_ADMIN_PORT            33062
 #define MYSQL_PORT_DEFAULT          0
 #define MYSQL_UNIX_ADDR            "/var/run/mysqld/mysqld.sock"
 #define MYSQL_CONFIG_NAME          "my"
-#define MYSQL_COMPILATION_COMMENT  "MySQL Community Server (GPL)"
-#define LIBMYSQL_VERSION           "5.7.29"
-#define LIBMYSQL_VERSION_ID         50729
-#define SYS_SCHEMA_VERSION         "1.5.2"
+#define MYSQL_PERSIST_CONFIG_NAME  "mysqld-auto"
+#define MYSQL_COMPILATION_COMMENT  "MySQL Community - GPL"
+#define MYSQL_COMPILATION_COMMENT_SERVER  "MySQL Community Server - GPL"
+#define LIBMYSQL_VERSION           "8.0.28"
+#define LIBMYSQL_VERSION_ID         80028
 
 #ifndef LICENSE
 #define LICENSE                     GPL
